summaryrefslogtreecommitdiff
path: root/src/configuration/Appconfig.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/configuration/Appconfig.py')
-rw-r--r--src/configuration/Appconfig.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/configuration/Appconfig.py b/src/configuration/Appconfig.py
index d1b82166..542c0b3f 100644
--- a/src/configuration/Appconfig.py
+++ b/src/configuration/Appconfig.py
@@ -11,7 +11,7 @@
# BUGS: ---
# NOTES: ---
# AUTHOR: Fahim Khan, fahim.elex@gmail.com
# ORGANIZATION: ecSim team at FOSSEE, IIT Bombay.
# CREATED: Wednesday 04 February 2015
# REVISION: ---
#===============================================================================
@@ -37,7 +37,7 @@ class Appconfig(QtGui.QWidget):
def __init__(self):
super(Appconfig, self).__init__()
#Application Details
- self._APPLICATION = 'ecSim'
+ self._APPLICATION = 'eSim'
self._VERSION = 'v1.1'
self._AUTHOR = 'Fahim'
@@ -11,7 +11,7 @@
# NOTES: ---
# AUTHOR: Fahim Khan, fahim.elex@gmail.com
-# ORGANIZATION: ecSim team at FOSSEE, IIT Bombay.
+# ORGANIZATION: eSim team at FOSSEE, IIT Bombay.
# CREATED: Wednesday 04 February 2015
# REVISION: ---